@@ -61,6 +61,7 @@ class MySQL:
             cur.execute(sql, param)
             rows = cur.fetchall()
         except Exception as e:
+            raise Exception(e)
             self._connect.rollback()
         cur.close()
         return rows
@@ -69,13 +70,11 @@ class MySQL:
         """
         exec DML：INSERT、UPDATE、DELETE
         :param sql: dml sql
+        :param param: string|list
         :return: Number of rows affected
         """
         try:
-            cnt = self.cursor.execute(sql)
+            self.cursor.execute(sql)
             self._connect.commit()
-            if cnt > 0:
-                return cnt
         except Exception as e:
             self._connect.rollback()
-            return -1
